@@ -32,15 +32,19 @@ class Content::Private : public QSharedData {
         QString m_id;  
         QString m_name;
         int m_downloads;
+        int m_numberOfComments;
         int m_rating;
         QDateTime m_created;
         QDateTime m_updated;
+        QList<Icon> m_icons;
+        QList<QUrl> m_videos;
 
         QMap<QString,QString> m_extendedAttributes;
 
         Private()
             : m_downloads(0),
-              m_rating(0)
+              m_rating(0),
+              m_numberOfComments(0)
         {
         }
 };
@@ -106,7 +110,17 @@ int Content::downloads() const
 {
   return d->m_downloads;
 }
-    
+
+void Content::setNumberOfComments(int v)
+{
+  d->m_numberOfComments = v;
+}
+
+int Content::numberOfComments() const
+{
+  return d->m_numberOfComments;
+}
+
 void Content::setCreated( const QDateTime &date )
 {
   d->m_created = date;
@@ -147,6 +161,11 @@ bool Content::isValid() const
   return !(d->m_id.isEmpty());
 }
 
+QString Content::summary() const
+{
+    return attribute("summary");
+}
+
 QString Content::description() const
 {
     return attribute("description");
@@ -195,20 +214,66 @@ Attica::DownloadDescription Attica::Content::downloadUrlDescription(int number)
     QString num(QString::number(number));
     DownloadDescription desc;
     
-    desc.setDownloadtypLink(true);
-    if (number == 1 && attribute("downloadtyp1") == "0") {
-        desc.setDownloadtypLink(false);
+    Attica::DownloadDescription::Type downloadType = Attica::DownloadDescription::LinkDownload;
+    if (attribute("downloadtyp" + num) == "0") {
+        downloadType = Attica::DownloadDescription::FileDownload;
+    } else if (attribute("downloadtyp" + num) == "1") {
+        downloadType = Attica::DownloadDescription::LinkDownload;
+    } else if (attribute("downloadtyp" + num) == "2") {
+        downloadType = Attica::DownloadDescription::PackageDownload;
     }
+    desc.setType(downloadType);
     desc.setId(number);
     desc.setName(attribute("downloadname" + num));
     desc.setDistributionType(attribute("downloadtype" + num));
     desc.setHasPrice(attribute("downloadbuy" + num) == "1");
     desc.setLink(attribute("downloadlink" + num));
-    // desc.setPriceReason(attribute("downloadreason" + num));
+    desc.setPriceReason(attribute("downloadreason" + num));
     desc.setPriceAmount(attribute("downloadprice" + num));
+    desc.setSize(attribute("downloadsize" + num).toUInt());
+    desc.setGpgFingerprint(attribute("downloadgpgfingerprint") + num);
+    desc.setGpgSignature(attribute("downloadgpgsignature") + num);
+    desc.setPackageName(attribute("downloadpackagename") + num);
+    desc.setRepository(attribute("downloadrepository") + num);
     return desc;
 }
 
+QList<HomePageEntry> Attica::Content::homePageEntries()
+{
+    QList<Attica::HomePageEntry> homepages;
+    QMap<QString,QString>::const_iterator iter = d->m_extendedAttributes.constBegin();
+    while (iter != d->m_extendedAttributes.constEnd()) {
+        QString key = iter.key();
+        if (key.startsWith(QLatin1String("homepagetype"))) {
+            bool ok;
+            // remove "homepage", get the rest as number
+            int num = key.right(key.size() - 12).toInt(&ok);
+            if (ok) {
+                // check if the homepage actually has a valid type
+                if (!iter.value().isEmpty()) {
+                    homepages.append(homePageEntry(num));
+                }
+            }
+        }
+        ++iter;
+    }
+
+    return homepages;
+}
+
+Attica::HomePageEntry Attica::Content::homePageEntry(int number) const
+{
+    QString num(QString::number(number));
+    HomePageEntry homepage;
+
+    if (number == 1 && attribute("homepage1").isEmpty()) {
+        num.clear();
+    }
+    homepage.setType(attribute("homepagetype" + num));
+    homepage.setUrl(attribute("homepage" + num));
+    return homepage;
+}
+
 QString Attica::Content::version() const
 {
     return attribute("version");
@@ -224,6 +289,11 @@ QString Attica::Content::license() const
     return attribute("licensetype");
 }
 
+QString Attica::Content::licenseName() const
+{
+    return attribute("license");
+}
+
 QString Attica::Content::previewPicture(const QString& number) const
 {
     return attribute("previewpic" + number);
@@ -233,3 +303,23 @@ QString Attica::Content::smallPreviewPicture(const QString& number) const
 {
     return attribute("smallpreviewpic" + number);
 }
+
+QList<Icon> Attica::Content::icons()
+{
+    return d->m_icons;
+}
+
+void Attica::Content::setIcons(QList<Icon> icons)
+{
+    d->m_icons = icons;
+}
+
+QList<QUrl> Attica::Content::videos()
+{
+    return d->m_videos;
+}
+
+void Attica::Content::setVideos(QList<QUrl> videos)
+{
+    d->m_videos = videos;
+}
