@@ -35,7 +35,10 @@
 #include "itemjob.h"
 #include "listjob.h"
 #include "message.h"
-         
+#include "comment.h"
+#include "distribution.h"
+#include "license.h"
+
 class QDate;
 class QUrl;
 
@@ -45,17 +48,20 @@ class PlatformDependent;
 
 class PostJobStatus;
 
+class AccountBalance;
 class Activity;
+class PrivateData;
 class Content;
 class DownloadItem;
+class Distribution;
 class Event;
 class Folder;
+class HomePageType;
 class KnowledgeBaseEntry;
 class License;
 class Person;
 class PostJob;
 class Provider;
-class AccountBalance;
 
 
 /**
@@ -245,6 +251,32 @@ class ATTICA_EXPORT Provider
     ListJob<Person>* requestPersonSearchByLocation(qreal latitude, qreal longitude, qreal distance = 0.0, int page = 0, int pageSize = 20);
     PostJob* postLocation(qreal latitude, qreal longitude, const QString& city = QString(), const QString& country = QString());
 
+    //////////////////////////
+    // PrivateData part of OCS
+
+    /**
+     * Fetches the a given attribute from an OCS-compliant server.
+     * @param app The application name
+     * @param key The key of the attribute to fetch (optional)
+     * @return The job that is responsible for fetching the data
+     */
+    ItemJob<PrivateData>* requestPrivateData(const QString& app, const QString& key = QString());
+
+    /**
+     * Fetches all stored private data.
+     * @return The job responsible for fetching data
+     */
+    ItemJob<PrivateData>* requestPrivateData() { return requestPrivateData(QString(), QString()); }
+
+    /**
+     * Sets the value of an attribute.
+     * @param app The application name
+     * @param key The key of the attribute
+     * @param value The new value of the attribute
+     * @return The job responsible for setting data
+     */
+    PostJob* setPrivateData(const QString &app, const QString &key, const QString &value);
+
     // Friend part of OCS
 
     ListJob<Person>* requestFriends(const QString& id, int page = 0, int pageSize = 20);
@@ -282,7 +314,19 @@ class ATTICA_EXPORT Provider
     * @return the licenses available from the server
     */
     ListJob<License>* requestLicenses();
-    
+
+    /**
+    * Get a list of distributions (such as Ark, Debian)
+    * @return the licenses available from the server
+    */
+    ListJob<Distribution>* requestDistributions();
+
+    /**
+    * Get a list of home page types (such as blog, Facebook)
+    * @return the licenses available from the server
+    */
+    ListJob<HomePageType>* requestHomePageTypes();
+
     /**
       Request a list of Contents.
       Note that @p categories is not optional. If left empty, no results will be returned.
@@ -303,6 +347,22 @@ class ATTICA_EXPORT Provider
      */
     ListJob<Content>* searchContentsByPerson(const Category::List& categories, const QString& person, const QString& search = QString(), SortMode mode = Rating, uint page = 0, uint pageSize = 10);
 
+    /**
+      Request a list of Contents. More complete version.
+      Note that @p categories is not optional. If left empty, no results will be returned.
+      An empty search string @p search returns the top n items.
+      @param categories categories to search in
+      @param person the person-id that created the contents
+      @param distributions list of distributions to filter by, if empty no filtering by distribution is done
+      @param licenses list of licenses to filter by, if empty no filtering by license is done
+      @param search optional search string (in name/description of the content)
+      @param mode sorting mode
+      @param page request nth page in the list of results
+      @param pageSize requested size of pages when calculating the list of results
+      @return list job for the search results
+      */
+    ListJob<Content>* searchContents(const Category::List& categories, const QString& person, const Distribution::List& distributions, const License::List& licenses, const QString& search = QString(), SortMode sortMode = Rating, uint page = 0, uint pageSize = 10);
+
     /**
       Retrieve a single content.
       @param contentId the id of the content
@@ -312,7 +372,20 @@ class ATTICA_EXPORT Provider
 
     ItemJob<DownloadItem>* downloadLink(const QString& contentId, const QString& itemId = QLatin1String("1"));
 
-    PostJob* voteForContent(const QString& contentId, bool positiveVote);
+    /** Vote for a content item
+     * This version is for the old OCS API < 1.6
+     * @param contentId the content which this voting is for
+     * @param positiveVote whether the voting is positive or negative
+     * @return the post job for this voting
+     */
+    Q_DECL_DEPRECATED PostJob* voteForContent(const QString& contentId, bool positiveVote);
+
+    /** Vote for a content item
+     * @param contentId the content which this voting is for
+     * @param rating - the rating, must be between 0 (bad) and 100 (good)
+     * @return the post job for this voting
+     */
+    PostJob* voteForContent(const QString& contentId, uint rating);
 
     ItemPostJob<Content>* addNewContent(const Category& category, const Content& newContent);
     ItemPostJob<Content>* editContent(const Category& updatedCategory, const QString& contentId, const Content& updatedContent);
@@ -341,6 +414,35 @@ class ATTICA_EXPORT Provider
     ItemJob<Event>* requestEvent(const QString& id);
     ListJob<Event>* requestEvent(const QString& country, const QString& search, const QDate& startAt, SortMode mode, int page, int pageSize);
 
+    // Comment part of OCS
+    /** Request a list of comments for a content / forum / knowledgebase / event.
+     * @param comment::Type type of the comment @see Comment::Type (content / forum / knowledgebase / event)
+     * @param id id of the content entry where you want to get the comments is from
+     * @param id2 id of the content entry where you want to get the comments is from
+     * @param page request nth page in the list of results
+     * @param pageSize requested size of pages when calculating the list of results
+     * @return list job for the comments results
+     */
+    ListJob<Comment>* requestComments(const Comment::Type commentType, const QString& id, const QString& id2, int page, int pageSize);
+
+    /** Add a new comment.
+     * @param commentType type of the comment @see CommentType (content / forum / knowledgebase / event)
+     * @param id id of the content entry where you want to get the comments is from
+     * @param id2 id of the sub content entry where you want to get the comments is from
+     * @param parentId the id of the parent comment if the new comment is a reply
+     * @param subject title of the comment
+     * @param message text of the comment
+     * @return post job for adding the new comment
+     */
+    PostJob* addNewComment(const Comment::Type commentType, const QString& id, const QString& id2, const QString& parentId, const QString &subject, const QString& message);
+
+    /** Vote a comment item
+     * @param id the comment id which this voting is for
+     * @param rating the rating, must be between 0 (bad) and 100 (good)
+     * @return the post job for this voting
+     */
+    PostJob* voteForComment(const QString & id, uint rating);
+
     // Fan part of OCS
 
     PostJob* becomeFan(const QString& contentId);
@@ -368,7 +470,7 @@ class ATTICA_EXPORT Provider
              const QString& person, const QString& friendV, const QString& message,
              const QString& activity, const QString& content, const QString& fan,
              const QString& knowledgebase, const QString& event, const QString& comment);
-    
+
 friend class ProviderManager;
 };
 }
